/*
               Editor Find In Pages Dialog: Operations
 */

#ifndef EDITORFIPOP_H
#define EDITORFIPOP_H

#include <gtk/gtk.h>
#include "editor.h"
#include "editorfip.h"


extern gint EditorFIPDoFind(
	editor_fip_struct *fip,
	editor_struct *editor,
	gint throughness,		/* 0 = match all, 1 = match any */
	const gchar *string,
	gboolean case_sensitive
);


#endif	/* EDITORFIPOP_H */
